package edu.whut.smilepicturebackend.model.enums;

import cn.hutool.core.util.ObjUtil;
import lombok.Getter;

/**
 * 图片审核状态枚举类
 */
@Getter
public enum PictureReviewStatusEnum {

    REVIEWING("待审核", 0),
    PASS("通过", 1),
    REJECT("拒绝", 2);

    private final String text;

    private final int value;

    PictureReviewStatusEnum(String text, int value) {
        this.text = text;
        this.value = value;
    }

    /**
     * 根据 value 获取枚举
     *
     * @param value 枚举值的 value
     * @return 枚举值
     */
    public static PictureReviewStatusEnum getEnumByValue(Integer value) {
        //判空：如果传进来的 value 为 null，直接返回 null
        if (ObjUtil.isEmpty(value)) {
            return null;
        }
        //遍历当前枚举类的所有常量
        for (PictureReviewStatusEnum pictureReviewStatusEnum : PictureReviewStatusEnum.values()) {
            //逐个比对内部的 value 字段
            if (pictureReviewStatusEnum.value == value) {
                //找到匹配的就立即返回对应枚举常量
                return pictureReviewStatusEnum;
            }
        }
        //如果没有任何枚举的 value 与之匹配，返回 null
        return null;
    }
}
